@@ -28,11 +28,18 @@
 #include <stdlib.h>
 #include <glib/gprintf.h>
 
+#include "xfce4-mpc-plugin.h"
+
 #define DEFAULT_MPD_HOST "localhost"
 #define DEFAULT_MPD_PORT 6600
 #define DIALOG_ENTRY_WIDTH 20
 
-#include "xfce4-mpc-plugin.h"
+#ifdef LIBXFCE4PANEL_CHECK_VERSION
+#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+#define HAS_PANEL_49
+#endif
+#endif
+
 
 static void
 mpc_free (XfcePanelPlugin * plugin, t_mpc * mpc)
@@ -43,7 +50,7 @@ mpc_free (XfcePanelPlugin * plugin, t_mpc * mpc)
    g_free (mpc);
 }
 
-#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+#ifdef HAS_PANEL_49
 static void
 mpc_set_mode (XfcePanelPlugin * plugin, XfcePanelPluginMode mode, t_mpc * mpc)
 {
@@ -55,6 +62,7 @@ mpc_set_mode (XfcePanelPlugin * plugin, XfcePanelPluginMode mode, t_mpc * mpc)
       GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
 
    xfce_hvbox_set_orientation(XFCE_HVBOX(mpc->box), orientation);
+   xfce_panel_plugin_set_small (plugin, (mode != XFCE_PANEL_PLUGIN_MODE_DESKBAR));
 }
 
 #else
@@ -70,7 +78,7 @@ mpc_set_orientation (XfcePanelPlugin * plugin, GtkOrientation orientation, t_mpc
 static gboolean
 mpc_set_size (XfcePanelPlugin * plugin, int size, t_mpc * mpc)
 {
-#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+#ifdef HAS_PANEL_49
     size /= xfce_panel_plugin_get_nrows (plugin);
 #endif
 
@@ -826,8 +834,9 @@ mpc_construct (XfcePanelPlugin * plugin)
    g_signal_connect (plugin, "free-data", G_CALLBACK (mpc_free), mpc);
    g_signal_connect (plugin, "save", G_CALLBACK (mpc_write_config), mpc);
    g_signal_connect (plugin, "size-changed", G_CALLBACK (mpc_set_size), mpc);
-#if defined (LIBXFCE4PANEL_CHECK_VERSION) && LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
+#ifdef HAS_PANEL_49
    g_signal_connect (plugin, "mode-changed", G_CALLBACK (mpc_set_mode), mpc);
+   xfce_panel_plugin_set_small (plugin, TRUE);
 #else
    g_signal_connect (plugin, "orientation-changed", G_CALLBACK (mpc_set_orientation), mpc);
 #endif
